OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Používateľská relácia sa neočakávane prerušila",
    "Provided email-address is not valid" : "Zadaná adresa e-mailu nie je platná",
    "%s has published the calendar »%s«" : "Používateľ %s zverejnil kalendár %s",
    "Unexpected error sending email. Please contact your administrator." : "Neočakávaná chyba počas odosielania e-mailu. Obráťte sa na správcu",
    "Successfully sent email to %1$s" : "E-mail bol úspešne odoslaný pre %1$s",
    "Hello," : "Ahoj,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Chceme vás upozorniť, že používateľ %s zverejnil kalendár %s",
    "Open »%s«" : "Otvoriť »%s«",
    "Cheers!" : "Pekný deň!",
    "Upcoming events" : "Nadchádzajúce udalosti",
    "Calendar" : "Kalendár",
    "A Calendar app for Nextcloud" : "Aplikácia Kalendár pre Nextcloud",
    "Previous day" : "Predchádzajúci deň",
    "Previous week" : "Predchádzajúci týždeň",
    "Previous month" : "Predchádzajúci mesiac",
    "Next day" : "Nasledujúci deň",
    "Next week" : "Nasledujúci týždeň",
    "Next month" : "Nasledujúci mesiac",
    "+ New event" : "+ Nová udalosť",
    "Today" : "Dnes",
    "Day" : "Deň",
    "Week" : "Týždeň",
    "Month" : "Mesiac",
    "List" : "Zoznam",
    "Untitled calendar" : "Kalendár bez názvu",
    "Edit name" : "Upraviť názov",
    "Saving name …" : "Ukladanie názvu …",
    "Edit color" : "Upraviť farbu",
    "Saving color …" : "Ukladanie farby …",
    "Copy private link" : "Kopírovať privátny odkaz",
    "Download" : "Sťahovanie",
    "Unshare from me" : "Zrušiť zdieľanie so mnou",
    "Delete" : "Zmazať",
    "An error occurred, unable to change visibility of the calendar." : "Vyskytla sa chyba, nie je možné zmeniť viditeľnosť kalendára.",
    "An error occurred, unable to delete the calendar." : "Vyskytla sa chyba, nie je možné zmazať kalendár.",
    "Calendar link copied to clipboard." : "Odkaz na kalendár skopírovaný do schránky.",
    "Calendar link could not be copied to clipboard." : "Odkaz na kalendár nebolo možné  skopírovať do schránky.",
    "An error occurred, unable to rename the calendar." : "Vyskytla sa chyba, nie je možné premenovať kalendár.",
    "An error occurred, unable to change the calendar's color." : "Vyskytla sa chyba, nie je možné zmeniť farbu kalendára.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Zdieľanie kalendára bude zmazané za {countdown} sekundu","Zdieľanie kalendára bude zmazané za {countdown} sekundy","Zdieľanie kalendára bude zmazané za {countdown} sekúnd","Zdieľanie kalendára bude zmazané za {countdown} sekúnd"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Kalendár bude zmazaný za {countdown} sekundu","Kalendár bude zmazaný za {countdown} sekundy","Kalendár bude zmazaný za {countdown} sekúnd","Kalendár bude zmazaný za {countdown} sekúnd"],
    "Share link" : "Sprístupniť odkaz",
    "Publish calendar" : "Zverejniť kalendár",
    "Publishing calendar" : "Zverejňovať kalendár",
    "Copy public link" : "Kopírovať verejný odkaz",
    "Send link to calendar via email" : "Odoslať odkaz na kalendár emailom",
    "Enter one address" : "Zadajte jednu adresu",
    "Sending email …" : "Odosielanie e-mailu …",
    "Copy subscription link" : "Kopírovať odkaz na odber",
    "Copying link …" : "Kopírovanie odkazu …",
    "Copied link" : "Kopírovaný odkaz",
    "Could not copy link" : "Nie je možné skopírovať odkaz",
    "Copy embedding code" : "Kopírovať vložený kód",
    "Copying code …" : "Kopírovanie kódu …",
    "Copied code" : "Skopírovaný kód",
    "Could not copy code" : "Nie je možné skopírovať kód",
    "Delete share link" : "Zmazať sprístupnený odkaz",
    "Deleting share link …" : "Mazanie odkazu pre sprístupnenie …",
    "An error occurred, unable to publish calendar." : "Vyskytla sa chyba, nie je možné zverejniť kalendár.",
    "An error occurred, unable to send email." : "Vyskytla sa chyba, nepodarilo sa odoslať e-mail.",
    "Embed code copied to clipboard." : "Vložený kód skopírovaný do schránky",
    "Embed code could not be copied to clipboard." : "Vložený kód nebolo možné  skopírovať do schránky.",
    "Unpublishing calendar failed" : "Zrušenie zverejnenia kalendára zlyhalo",
    "Share with users or groups" : "Sprístupniť používateľom alebo skupinám",
    "No users or groups" : "Žiadni používatelia alebo skupiny",
    "can edit" : "môže upraviť",
    "Unshare with {displayName}" : "Zrušiť zdieľanie s {displayName}",
    "An error occurred, unable to change the unshare the calendar." : "Vyskytla sa chyba, nie je možné zmeniť zdieľanie kalendára.",
    "An error occurred, unable to change the permission of the share." : "Vyskytla sa chyba, nie je možné zmeniť práva na zdieľanie kalendára.",
    "+ New calendar" : "+ Nový kalendár",
    "New calendar" : "Nový kalendár",
    "Creating calendar …" : "Vytváranie kalendára …",
    "New calendar with task list" : "Nový kalendár so zoznamom úloh",
    "New subscription from link (read-only)" : "Nový odber z odkazu (iba na čítanie)",
    "Creating subscription …" : "Vytvára sa odber …",
    "An error occurred, unable to create the calendar." : "Vyskytla sa chyba, nie je možné vytvoriť kalendár.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Vkladajte platné odkazy (musia sa začínať http://, https://, webcal:// alebo webcals://)",
    "Trash bin" : "Kôš",
    "Name" : "Názov",
    "Deleted" : "Zmazané",
    "Restore" : "Obnoviť",
    "Delete permanently" : "Zmazať  natrvalo",
    "Untitled event" : "Udalosť bez názvu",
    "Could not load deleted calendars and objects" : "Nie je možné načítať zmazané kalendáre a objekty",
    "Could not restore calendar or event" : "Nie je možné obnoviť kalendár alebo udalosť",
    "Could not update calendar order." : "Poradie kalendára sa nepodarilo aktualizovať.",
    "Import calendars" : "Import kalendára",
    "Please select a calendar to import into …" : "Vyberte kalendár do ktorého importovať …",
    "Filename" : "Názov súboru",
    "Calendar to import into" : "Kalendár na import do ...",
    "Cancel" : "Zrušiť",
    "_Import calendar_::_Import calendars_" : ["Import kalendára","Import kalendárov","Import kalendárov","Import kalendárov"],
    "{filename} is an unsupported file-type" : "{filename} nie je podporovaný typ súboru",
    "{filename} could not be parsed" : "{filename} nie je možné spracovať",
    "No valid files found, aborting import" : "Nenašli sa žiadne platné súbory, import sa prerušuje",
    "Import partially failed. Imported {accepted} out of {total}." : "Import čiastočne zlyhal. Importované {accepted} z {total}.",
    "_Successfully imported %n event_::_Successfully imported %n events._" : ["Úspešne naimportovaná %n udalosť.","Úspešne naimportované %n udalosti.","Úspešne naimportovaných %n udalostí.","Úspešne naimportovaných %n udalostí."],
    "Automatic" : "Automaticky",
    "Automatic ({detected})" : "Automaticky ({detected})",
    "New setting was not saved successfully." : "Nové nastavenie nebolo možné uložiť.",
    "Shortcut overview" : "Stručný prehľad",
    "or" : "alebo",
    "Navigation" : "Navigácia",
    "Previous period" : "Predchádzajúce obdobie",
    "Next period" : "Nadchádzajúce obdobie",
    "Views" : "Zobrazenia",
    "Day view" : "Denné zobrazenie",
    "Week view" : "Týždenné zobrazenie",
    "Month view" : "Mesačné zobrazenie",
    "List view" : "Zobraziť ako zoznam",
    "Actions" : "Akcie",
    "Create event" : "Vytvoriť udalosť",
    "Show shortcuts" : "Zobraziť skratky",
    "Enable birthday calendar" : "Povoliť narodeninový kalendár",
    "Show tasks in calendar" : "Zobraziť úlohy v kalendári",
    "Enable simplified editor" : "Povoliť zjednodušený editor",
    "Limit visible events per view" : "Obmedziť viditeľné udalosti v jednotlivých pohľadoch",
    "Show weekends" : "Zobraziť víkendy",
    "Show week numbers" : "Zobraziť čísla týždňov",
    "Default reminder" : "Predvolená pripomienka",
    "Copy primary CalDAV address" : "Kopírovať primárnu CalDAV adresu",
    "Copy iOS/macOS CalDAV address" : "Kopírovať iOS/macOS CalDAV adresu",
    "Show keyboard shortcuts" : "Zobraziť klávesové skratky",
    "Settings & import" : "Nastavenia a import",
    "No reminder" : "Žiadna pripomienka",
    "CalDAV link copied to clipboard." : "Odkaz CalDAV skopírovaný do schránky.",
    "CalDAV link could not be copied to clipboard." : "Odkaz CalDAV nebolo možné skopírovať do schránky.",
    "before at" : "pred o",
    "Notification" : "Hlásenie",
    "Email" : "E-mail",
    "Audio notification" : "Hlasový oznam",
    "Other notification" : "Ostatné hlásenia",
    "Relative to event" : "Prislúchajúci k udalosti",
    "On date" : "Dňa",
    "Edit time" : "Zmeniť čas pripomienky",
    "Save time" : "Uložiť zmenený čas pripomienky",
    "Remove reminder" : "Odstrániť pripomienku",
    "on" : "o",
    "at" : "na",
    "+ Add reminder" : "+ Pridať pripomienku",
    "_second_::_seconds_" : ["sekunda","sekundy","sekúnd","sekúnd"],
    "_minute_::_minutes_" : ["minúta","minúty","minút","minút"],
    "_hour_::_hours_" : ["hodina","hodiny","hodín","hodín"],
    "_day_::_days_" : ["deň","dni","dní","dní"],
    "_week_::_weeks_" : ["týždeň","týždne","týždňov","týždňov"],
    "No reminders yet" : "Žiadne pripomienky",
    "Availability of attendees, resources and rooms" : "Dostupnosť účastníkov, zdrojov a miestností",
    "{organizer} (organizer)" : "{organizer} (organizátor)",
    "Free" : "Voľný",
    "Busy (tentative)" : "Zaneprázdnený (predbežne)",
    "Busy" : "Zaneprázdnený",
    "Out of office" : "Mimo kancelárie",
    "Unknown" : "Neznámy",
    "Available." : "Dostupné.",
    "Not available." : "Nedostupné.",
    "Invitation accepted." : "Pozvánka prijatá.",
    "Invitation sent." : "Pozvánka odoslaná.",
    "Create Talk room for this event" : "Vytvoriť pre túto udalosť miestnosť v Talk",
    "Show busy times" : "Zobraziť časy zaneprázdnenosti",
    "Successfully appended link to talk room to description." : "Do popisu bol úspešne pridaný odkaz na miestnosť v Talk",
    "Error creating Talk room" : "Chyba pri vytváraní miestnosti v Talk",
    "Send email" : "Odoslať email",
    "Chairperson" : "Predseda",
    "Required participant" : "Požadovaná účasť",
    "Optional participant" : "Nepovinná účasť",
    "Non-participant" : "Bez účasti",
    "Remove attendee" : "Odstrániť účastníka",
    "No match found" : "Nenašla sa žiadna zhoda",
    "No attendees yet" : "Zatiaľ žiadni účastníci",
    "(organizer)" : "(organizátor)",
    "Remove color" : "Odobrať farbu",
    "Event title" : "Názov udalosti",
    "All day" : "Celý deň",
    "from {startDate}" : "od {startDate}",
    "from {startDate} at {startTime}" : "od {startDate} o {startTime}",
    "to {endDate}" : "do {endDate}",
    "to {endDate} at {endTime}" : "do {endDate} o {endTime}",
    "End repeat" : "Koniec opakovania",
    "Select to end repeat" : "Vyberte koniec opakovania",
    "never" : "nikdy",
    "on date" : "dňa",
    "after" : "po",
    "_time_::_times_" : ["krát","krát","krát","krát"],
    "first" : "prvý",
    "third" : "tretie",
    "fourth" : "štvrté",
    "fifth" : "piate",
    "second to last" : "po koľko sekúnd",
    "last" : "posledné",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Zmeny v opakovanej udalosti budú mať vplyv len na túto a budúce udalosti.",
    "Repeat" : "Opakovať",
    "Repeat every" : "Opakovať každý",
    "By day of the month" : "Podľa dňa v mesiaci",
    "On the" : "V",
    "_month_::_months_" : ["mesiac","mesiace","mesiacov","mesiacov"],
    "_year_::_years_" : ["rok","roky","rokov","rokov"],
    "Monday" : "Pondelok",
    "weekday" : "deň v týždni",
    "weekend day" : "deň cez víkend",
    "Summary" : "Súhrn",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Definícia opakovania tejto udalosti nie je Nextcloud plne podporovaná. Ak upravíte možnosti opakovania, niektoré opakovania sa môžu stratiť.",
    "More" : "Viac",
    "Save" : "Uložiť",
    "Update" : "Aktualizovať",
    "Update this occurrence" : "Aktualizovať tento výskyt",
    "Update this and all future" : "Aktualizovať tento a všetky budúce",
    "Public calendar does not exist" : "Verejný kalendár neexistuje",
    "Maybe the share was deleted or has expired?" : "Možno bolo zrušené sprístupnenie alebo skončila jeho platnosť?",
    "Please select a timezone:" : "Vyberte časovú zónu:",
    "Pick a time" : "Vyberte čas",
    "Pick a date" : "Vyberte dátum",
    "from {formattedDate}" : "od {formattedDate}",
    "to {formattedDate}" : "do {formattedDate}",
    "on {formattedDate}" : "{formattedDate}",
    "from {formattedDate} at {formattedTime}" : "od {formattedDate} o {formattedTime}",
    "to {formattedDate} at {formattedTime}" : "do {formattedDate} o {formattedTime}",
    "on {formattedDate} at {formattedTime}" : "{formattedDate} o {formattedTime}",
    "{formattedDate} at {formattedTime}" : "{formattedDate} o {formattedTime}",
    "Please enter a valid date" : "Zadajte platný dátum",
    "Please enter a valid date and time" : "Zadajte platný dátum a čas",
    "Type to search timezone" : "Písaním nájdete časovú zónu",
    "Personal" : "Osobné",
    "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "Automatická detekcia časového pásma určila, že vaše časové pásmo je UTC.\nJe to pravdepodobne výsledok bezpečnostných opatrení vášho webového prehliadača.\nNastavte časové pásmo manuálne v nastaveniach kalendára.",
    "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "Vami nastavené časové pásmo ({timezoneId}) sa nenašlo. Nastavené bolo UTC.\nZmeňte v nastaveniach svoje časové pásmo a nahláste tento problém.",
    "No more events today" : "Dnes žiadne ďalšie udalosti",
    "No upcoming events" : "Žiadne nadchádzajúce udalosti",
    "Create a new event" : "Vytvoriť novú udalosť",
    "[Today]" : "[Dnes]",
    "[Tomorrow]" : "[Zajtra]",
    "[Yesterday]" : "[Včera]",
    "Delete this occurrence" : "Vymazať tento výskyt",
    "Delete this and all future" : "Vymazať toto a všetko budúce",
    "Details" : "Podrobnosti",
    "Attendees" : "Účastníci",
    "Reminders" : "Pripomienky",
    "Close" : "Zavrieť",
    "Show more details" : "Zobraziť ďalšie podrobnosti",
    "Subscribe to {name}" : "Prihlásiť sa na odber {name}",
    "Download {name}" : "Prevziať",
    "Anniversary" : "Výročie",
    "Appointment" : "Stretnutie",
    "Business" : "Služobné",
    "Education" : "Výuka",
    "Holiday" : "Sviatok",
    "Meeting" : "Porada",
    "Miscellaneous" : "Rôzne",
    "Non-working hours" : "Mimopracovné hodiny",
    "Not in office" : "Mimo kancelárie",
    "Phone call" : "Telefonát",
    "Sick day" : "Práceneschopnosť",
    "Special occasion" : "Špeciálna príležitosť",
    "Travel" : "Cestovanie",
    "Vacation" : "Dovolenka",
    "Midnight on the day the event starts" : "Najbližšia polnoc pred začiatkom udalosti",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n deň pred udalosťou o {formattedHourMinute}","%n dni pred udalosťou o {formattedHourMinute}","%n dní pred udalosťou o {formattedHourMinute}","%n dní pred udalosťou o {formattedHourMinute}"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n týždeň pred udalosťou o {formattedHourMinute}","%n týždne pred udalosťou o {formattedHourMinute}","%n týždňov pred udalosťou o {formattedHourMinute}","%n týždňov pred udalosťou o {formattedHourMinute}"],
    "on the day of the event at {formattedHourMinute}" : "v deň udalosti o {formattedHourMinute}",
    "at the event's start" : "na začiatku udalosti",
    "at the event's end" : "na konci udalosti",
    "{time} before the event starts" : "{time} pred začiatkom udalosti",
    "{time} before the event ends" : "{time} pred koncom udalosti",
    "{time} after the event starts" : "{time} po začiatku udalosti",
    "{time} after the event ends" : "{time} po skončení udalosti",
    "on {time}" : "o {time}",
    "on {time} ({timezoneId})" : "o {time} ({timezoneId})",
    "Week {number} of {year}" : "Týždeň {number} roku {year}",
    "Does not repeat" : "Neopakuje sa",
    "Daily" : "Denne",
    "Weekly" : "Týždenne",
    "Monthly" : "Mesačne",
    "Yearly" : "Ročne",
    "_Every %n day_::_Every %n days_" : ["Každý deň","Každé %n dni","Každých %n dní","Každých %n dní"],
    "_Every %n week_::_Every %n weeks_" : ["Každý týždeň","Každé %n týždne","Každých %n týždňov","Každých %n týždňov"],
    "_Every %n month_::_Every %n months_" : ["Každý mesiac","Každé %n mesiace","Každých %n mesiacov","Každých %n mesiacov"],
    "_Every %n year_::_Every %n years_" : ["Každý rok","Každé %n rokov","Každých %n rokov","Každých %n rokov"],
    "_on {weekday}_::_on {weekdays}_" : ["v {weekday}","v {weekday}","v {weekday}","v {weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["v dni {dayOfMonthList}","v dňoch {dayOfMonthList}","v dňoch {dayOfMonthList}","v dňoch {dayOfMonthList}"],
    "on the {ordinalNumber} {byDaySet}" : "každý mesiac {ordinalNumber} {byDaySet}",
    "in {monthNames}" : "v {monthNames}",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "v {monthNames} v {ordinalNumber} {byDaySet}",
    "until {untilDate}" : "do {untilDate}",
    "_%n time_::_%n times_" : ["%n raz","%n raz","%n raz","%n raz"],
    "Untitled task" : "Úloha bez názvu",
    "Please ask your administrator to enable the Tasks App." : "Požiadajte svojho správcu, aby povolil aplikáciu Úlohy.",
    "Prev" : "Predch",
    "Next" : "Ďalšie",
    "Year" : "Rok",
    "%n more" : "%n ďalších",
    "No events to display" : "Žiadne udalosti k zobrazeniu",
    "_+%n more_::_+%n more_" : ["+%n ďalší","+%n ďalší","+%n ďalší","+%n ďalších"],
    "No events" : "Žiadne udalosti",
    "When shared show" : "Pri zdieľaní zobraziť",
    "When shared show full event" : "Pri zdieľaní zobraziť udalosť úplne",
    "When shared show only busy" : "Pri zdieľaní zobraziť len zaneprázdnený",
    "When shared hide this event" : "Pri zdieľaní skryť udalosť",
    "The visibility of this event in shared calendars." : "Viditeľnosť tejto udalosti v zdieľaných kalendároch.",
    "Location" : "Umiestnenie",
    "Add a location" : "Zadajte umiestnenie",
    "Description" : "Popis",
    "Add a description" : "Zadajte popis",
    "Status" : "Stav",
    "Confirmed" : "Potvrdené",
    "Tentative" : "Neistý",
    "Canceled" : "Zrušené",
    "Confirmation about the overall status of the event." : "Potvrdenie o celkovom stave udalosti.",
    "Show as" : "Zobrazovať ako",
    "Take this event into account when calculating free-busy information." : "Zohľadniť túto udalosť pri určovaní zaneprázdnených/voľných hodín. ",
    "Categories" : "Kategórie",
    "Categories help you to structure and organize your events." : "Kategórie pomáhajú udržiavať prehľad v udalostiach a štruktúrovať ich.",
    "Search or add categories" : "Hľadať alebo pridať kategórie",
    "Add this as a new category" : "Pridať ako novú kategóriu",
    "Custom color" : "Vlastná farba",
    "Special color of this event. Overrides the calendar-color." : "Špeciálna farba tejto udalosti. Prepíše farbu kalendára.",
    "Chat room for event" : "Chatová miestnosť pre udalosť",
    "Imported {filename}" : "Importované {filename}",
    "Meditation" : "Meditácia",
    "Relaxing" : "Odpočinok",
    "Relax" : "Odpočinok",
    "Presentation" : "Prezentácia",
    "Present" : "Prezentovať",
    "Camping" : "Táborenie",
    "Camp" : "Kempovanie",
    "Movie" : "Film",
    "Cinema" : "Kino",
    "Graduation" : "Štátnice",
    "Brainstorm" : "Porada",
    "Baseball" : "Bejzbal",
    "Meet" : "Stretnutie",
    "Planning" : "Plánovanie",
    "Pointing" : "Ukazovanie",
    "Retrospective" : "Retrospektíva",
    "Review" : "Preskúmať",
    "Office" : "Kancelária",
    "Contributor week" : "Týždeň prispievateľov",
    "Mail" : "Pošta",
    "Soccer" : "futbal",
    "Football" : "Futbal",
    "Gaming" : "Hranie",
    "Drive" : "Šoférovať",
    "Bicycle" : "Bicykel",
    "Cycle" : "Bicyklovať",
    "Biking" : "Bicyklovanie",
    "Bike" : "Bycikel",
    "Podcast" : "Podcast",
    "Basketball" : "Basketbal",
    "Fishing" : "Rybačka",
    "Hiking" : "Turistika",
    "Hike" : "Túra",
    "Art" : "Umenie",
    "Exhibition" : "Výstava",
    "Museum" : "Múzeum",
    "Pilates" : "Cvičenie",
    "Park" : "Park",
    "Studying" : "Učiť sa",
    "Doctor" : "Doktor",
    "Health" : "Zdravie",
    "Dentist" : "Zubár",
    "Interview" : "Pohovor",
    "Training" : "Tréning",
    "Practice" : "Tréning",
    "Sports" : "Šport",
    "Exercise" : "Cvičenie",
    "Work out" : "Posilovňa",
    "Working out" : "Posilovať",
    "Gym" : "Fitko",
    "Barber" : "Holič",
    "Haircut" : "Účes",
    "Exam" : "Skúška",
    "Working" : "Práca",
    "New Years Eve" : "Nový rok",
    "NYE" : "Silvester",
    "Fireworks" : "ohňostroj",
    "Running" : "beh",
    "Go for a run" : "behať",
    "Marathon" : "Maratón",
    "Video-conference" : "Video-konferencia",
    "Conference-call" : "Konferenčný hovor",
    "Video-call" : "Video-hovor",
    "Video-chat" : "Video-čet",
    "Video-meeting" : "Video-stretnutie",
    "Call" : "Telefonát",
    "Calling" : "Zavolať",
    "Christmas" : "Vianoce",
    "Conference" : "Konferencia",
    "Pizza" : "Pizza",
    "Travelling" : "Cestovanie",
    "Journey" : "Cestovanie",
    "Collaborate" : "Spolupracovať",
    "Pair" : "Dvojica",
    "Lecture" : "Prednáška",
    "Seminar" : "Seminár",
    "Photograph" : "Fotografovať",
    "Party" : "Párty",
    "Celebration" : "Oslava",
    "Celebrate" : "Oslava",
    "Shopping" : "Nakupovanie",
    "Skate" : "Korčulovanie",
    "Skateboard" : "Skateboard",
    "Wine tasting" : "Ochutnávka vína",
    "Golf" : "Golf",
    "Dinner" : "Večera",
    "Lunch" : "Obed",
    "Global" : "Globálne"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
